// -*- c++ -*-
// Generated by gtkmmproc -- DO NOT MODIFY!
#ifndef _GTKMM_ADJUSTMENT_H
#define _GTKMM_ADJUSTMENT_H


#include <glibmm.h>

/* $Id: adjustment.hg,v 1.5 2006/11/08 21:51:35 murrayc Exp $ */

/* adjustment.h
 * 
 * Copyright (C) 1998-2002 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtkmm/object.h>


#ifndef DOXYGEN_SHOULD_SKIP_THIS
typedef struct _GtkAdjustment GtkAdjustment;
typedef struct _GtkAdjustmentClass GtkAdjustmentClass;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


namespace Gtk
{ class Adjustment_Class; } // namespace Gtk
namespace Gtk
{

/** A class representing an adjustable bounded value.
 *
 * The Gtk::Adjustment object represents a value which has an associated
 * lower and upper bound, together with step and page increments, and a page
 * size.  It is used within several gtkmm widgets, including
 * Gtk::SpinButton, Gtk::Viewport, and Gtk::Range (which is a base class for
 * Gtk::HScrollbar, Gtk::VScrollbar, Gtk::HScale, and Gtk::VScale).
 *
 * The Gtk::Adjustment object does not update the value itself. Instead it
 * is left up to the owner of the Gtk::Adjustment to control the value.
 *
 * The owner of the Gtk::Adjustment typically calls the value_changed() and
 * changed() functions after changing the value and its bounds. This results
 * in the emission of the "value_changed" or "changed" signal respectively. 
 *
 */

class Adjustment : public Object
{
  public:
#ifndef DOXYGEN_SHOULD_SKIP_THIS
  typedef Adjustment CppObjectType;
  typedef Adjustment_Class CppClassType;
  typedef GtkAdjustment BaseObjectType;
  typedef GtkAdjustmentClass BaseClassType;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

  virtual ~Adjustment();

#ifndef DOXYGEN_SHOULD_SKIP_THIS

private:
  friend class Adjustment_Class;
  static CppClassType adjustment_class_;

  // noncopyable
  Adjustment(const Adjustment&);
  Adjustment& operator=(const Adjustment&);

protected:
  explicit Adjustment(const Glib::ConstructParams& construct_params);
  explicit Adjustment(GtkAdjustment* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:
#ifndef DOXYGEN_SHOULD_SKIP_THIS
  static GType get_type()      G_GNUC_CONST;


  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GtkObject.
  GtkAdjustment*       gobj()       { return reinterpret_cast<GtkAdjustment*>(gobject_); }

  ///Provides access to the underlying C GtkObject.
  const GtkAdjustment* gobj() const { return reinterpret_cast<GtkAdjustment*>(gobject_); }


public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::
  virtual void on_changed();
  virtual void on_value_changed();


private:

public:

  friend class Range;
  friend class HScrollbar;
  friend class VScrollbar;

  /** Constructor to create an Adjustment object.
   * @param value The initial value
   * @param lower The minimum value
   * @param upper The maximum value
   * @param step_increment The step increment
   * @param page_increment The page increment
   * @param page_size The page size
   */
  Adjustment(double value, double lower, double upper, double step_increment = 1, double page_increment = 10, double page_size = 0);
  
  
  /** Emits a "changed" signal from the Adjustment.  This is typically called by the owner of the Adjustment after it has changed any of the Adjustment fields other than the value.
   */
  void changed();
  
  /** Emits a "value_changed" signal from the Adjustment.  This is typically called by the owner of the Adjustment after it has changed the Adjustment value field.
   */
  void value_changed();

  
  /** Updates the Adjustment value to ensure that the range between the parameters @a lower and @a upper is in the current page (i.e.\ between @a value and @a value + @a page_size).  If this range is larger than the page size, then only the start of it will be in the current page.  A "changed" signal will be emitted if the value is changed.
   * @param upper The upper value.
   * @param lower The lower value.
   */
  void clamp_page(double lower, double upper);

  
  /** Sets the current value of the Adjustment
   * @param value The new value of the Adjustment.
   */
  void set_value(double value);
  
  /** Gets the current value of the adjustment. See
   * set_value().
   * @return The current value of the adjustment.
   */
  double get_value() const;


  /** Sets the minimum value of the adjustment.
   * 
   * When setting multiple adjustment properties via their individual
   * setters, multiple "changed" signals will be emitted. However, since
   * the emission of the "changed" signal is tied to the emission of the
   * "GObject::notify" signals of the changed properties, it's possible
   * to compress the "changed" signals into one by calling
   * Glib::object_freeze_notify() and Glib::object_thaw_notify() around the
   * calls to the individual setters.
   * 
   * Alternatively, using a single Glib::object_set() for all the properties
   * to change, or using configure() has the same effect
   * of compressing "changed" emissions.
   * 
   * @newin{2,14}
   * @param lower The new minimum value.
   */
  void set_lower(double lower);
  
  /** Retrieves the minimum value of the adjustment.
   * 
   * @newin{2,14}
   * @return The current minimum value of the adjustment.
   */
  double get_lower() const;
  
  
  /** Sets the maximum value of the adjustment.
   * 
   * Note that values will be restricted by
   * <tt>upper - page-size</tt> if the page-size
   * property is nonzero.
   * 
   * See set_lower() about how to compress multiple
   * emissions of the "changed" signal when setting multiple adjustment
   * properties.
   * 
   * @newin{2,14}
   * @param upper The new maximum value.
   */
  void set_upper(double upper);
  
  /** Retrieves the maximum value of the adjustment.
   * 
   * @newin{2,14}
   * @return The current maximum value of the adjustment.
   */
  double get_upper() const;

  
  /** Sets the step increment of the adjustment.
   * 
   * See set_lower() about how to compress multiple
   * emissions of the "changed" signal when setting multiple adjustment
   * properties.
   * 
   * @newin{2,14}
   * @param step_increment The new step increment.
   */
  void set_step_increment(double step_increment);
  
  /** Retrieves the step increment of the adjustment.
   * 
   * @newin{2,14}
   * @return The current step increment of the adjustment.
   */
  double get_step_increment() const;

  
  /** Sets the page increment of the adjustment.
   * 
   * See set_lower() about how to compress multiple
   * emissions of the "changed" signal when setting multiple adjustment
   * properties.
   * 
   * @newin{2,14}
   * @param page_increment The new page increment.
   */
  void set_page_increment(double page_increment);
  
  /** Retrieves the page increment of the adjustment.
   * 
   * @newin{2,14}
   * @return The current page increment of the adjustment.
   */
  double get_page_increment() const;

  
  /** Sets the page size of the adjustment.
   * 
   * See set_lower() about how to compress multiple
   * emissions of the "changed" signal when setting multiple adjustment
   * properties.
   * 
   * @newin{2,14}
   * @param page_size The new page size.
   */
  void set_page_size(double page_size);
  
  /** Retrieves the page size of the adjustment.
   * 
   * @newin{2,14}
   * @return The current page size of the adjustment.
   */
  double get_page_size() const;

  
  /** Sets all properties of the adjustment at once.
   * 
   * Use this function to avoid multiple emissions of the "changed"
   * signal. See set_lower() for an alternative way
   * of compressing multiple emissions of "changed" into one.
   * 
   * @newin{2,14}
   * @param value The new value.
   * @param lower The new minimum value.
   * @param upper The new maximum value.
   * @param step_increment The new step increment.
   * @param page_increment The new page increment.
   * @param page_size The new page size.
   */
  void configure(double value, double lower, double upper, double step_increment, double page_increment, double page_size);

  
  /**
   * @par Prototype:
   * <tt>void on_my_%changed()</tt>
   */

  Glib::SignalProxy0< void > signal_changed();

  
  /**
   * @par Prototype:
   * <tt>void on_my_%value_changed()</tt>
   */

  Glib::SignalProxy0< void > signal_value_changed();

  
  #ifdef GLIBMM_PROPERTIES_ENABLED
/** The value of the adjustment.
   *
   * You rarely need to use properties because there are get_ and set_ methods for almost all of them.
   * @return A PropertyProxy that allows you to get or set the property of the value, or receive notification when
   * the value of the property changes.
   */
  Glib::PropertyProxy<double> property_value() ;
#endif //#GLIBMM_PROPERTIES_ENABLED

#ifdef GLIBMM_PROPERTIES_ENABLED
/** The value of the adjustment.
   *
   * You rarely need to use properties because there are get_ and set_ methods for almost all of them.
   * @return A PropertyProxy that allows you to get or set the property of the value, or receive notification when
   * the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly<double> property_value() const;
#endif //#GLIBMM_PROPERTIES_ENABLED

  #ifdef GLIBMM_PROPERTIES_ENABLED
/** The minimum value of the adjustment.
   *
   * You rarely need to use properties because there are get_ and set_ methods for almost all of them.
   * @return A PropertyProxy that allows you to get or set the property of the value, or receive notification when
   * the value of the property changes.
   */
  Glib::PropertyProxy<double> property_lower() ;
#endif //#GLIBMM_PROPERTIES_ENABLED

#ifdef GLIBMM_PROPERTIES_ENABLED
/** The minimum value of the adjustment.
   *
   * You rarely need to use properties because there are get_ and set_ methods for almost all of them.
   * @return A PropertyProxy that allows you to get or set the property of the value, or receive notification when
   * the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly<double> property_lower() const;
#endif //#GLIBMM_PROPERTIES_ENABLED

  #ifdef GLIBMM_PROPERTIES_ENABLED
/** The maximum value of the adjustment.
   *
   * You rarely need to use properties because there are get_ and set_ methods for almost all of them.
   * @return A PropertyProxy that allows you to get or set the property of the value, or receive notification when
   * the value of the property changes.
   */
  Glib::PropertyProxy<double> property_upper() ;
#endif //#GLIBMM_PROPERTIES_ENABLED

#ifdef GLIBMM_PROPERTIES_ENABLED
/** The maximum value of the adjustment.
   *
   * You rarely need to use properties because there are get_ and set_ methods for almost all of them.
   * @return A PropertyProxy that allows you to get or set the property of the value, or receive notification when
   * the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly<double> property_upper() const;
#endif //#GLIBMM_PROPERTIES_ENABLED

  #ifdef GLIBMM_PROPERTIES_ENABLED
/** The step increment of the adjustment.
   *
   * You rarely need to use properties because there are get_ and set_ methods for almost all of them.
   * @return A PropertyProxy that allows you to get or set the property of the value, or receive notification when
   * the value of the property changes.
   */
  Glib::PropertyProxy<double> property_step_increment() ;
#endif //#GLIBMM_PROPERTIES_ENABLED

#ifdef GLIBMM_PROPERTIES_ENABLED
/** The step increment of the adjustment.
   *
   * You rarely need to use properties because there are get_ and set_ methods for almost all of them.
   * @return A PropertyProxy that allows you to get or set the property of the value, or receive notification when
   * the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly<double> property_step_increment() const;
#endif //#GLIBMM_PROPERTIES_ENABLED

  #ifdef GLIBMM_PROPERTIES_ENABLED
/** The page increment of the adjustment.
   *
   * You rarely need to use properties because there are get_ and set_ methods for almost all of them.
   * @return A PropertyProxy that allows you to get or set the property of the value, or receive notification when
   * the value of the property changes.
   */
  Glib::PropertyProxy<double> property_page_increment() ;
#endif //#GLIBMM_PROPERTIES_ENABLED

#ifdef GLIBMM_PROPERTIES_ENABLED
/** The page increment of the adjustment.
   *
   * You rarely need to use properties because there are get_ and set_ methods for almost all of them.
   * @return A PropertyProxy that allows you to get or set the property of the value, or receive notification when
   * the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly<double> property_page_increment() const;
#endif //#GLIBMM_PROPERTIES_ENABLED

  #ifdef GLIBMM_PROPERTIES_ENABLED
/** The page size of the adjustment.
   *
   * You rarely need to use properties because there are get_ and set_ methods for almost all of them.
   * @return A PropertyProxy that allows you to get or set the property of the value, or receive notification when
   * the value of the property changes.
   */
  Glib::PropertyProxy<double> property_page_size() ;
#endif //#GLIBMM_PROPERTIES_ENABLED

#ifdef GLIBMM_PROPERTIES_ENABLED
/** The page size of the adjustment.
   *
   * You rarely need to use properties because there are get_ and set_ methods for almost all of them.
   * @return A PropertyProxy that allows you to get or set the property of the value, or receive notification when
   * the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly<double> property_page_size() const;
#endif //#GLIBMM_PROPERTIES_ENABLED


};

} /* namespace Gtk */


namespace Glib
{
  /** A Glib::wrap() method for this object.
   * 
   * @param object The C instance.
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   *
   * @relates Gtk::Adjustment
   */
  Gtk::Adjustment* wrap(GtkAdjustment* object, bool take_copy = false);
} //namespace Glib


#endif /* _GTKMM_ADJUSTMENT_H */

